<?php
/**
 * @class wechatBalance
 * @brief 商家转账到零钱
 * @note  需要利用微信插件和公众号支付方式
 * @date 2022/9/10 17:38:38
 */
include_once(dirname(__FILE__)."/common/transferInter.php");
include_once(dirname(__FILE__)."/../payments/common/wechatBase.php");
class wechatBalance extends wechatBase implements transferInter
{
	//名称
    public $name = '商家转账到零钱';

	//构造函数 选择微信支付接口
	public function __construct()
	{
		$paymentDB = new IModel('payment');
		$paymentRow= $paymentDB->getObj('class_name like "%wechat%" and status = 0','id');
		if($paymentRow)
		{
			$this->paymentId = $paymentRow['id'];
		}
	}

	/**
	 * @brief 提交URL路径
	 * @return string
	 */
	public function getSubmitUrl()
	{
		return '/v3/transfer/batches';
	}

	public function getSendData($paymentInfo){}

	/**
	 * @brief 开始执行支付
	 * @param array $data 支付数据 [transferNo => '转款单号','transferName' => '转款名称','detail' => ['name' => '姓名','amount' => '金额','openid' => 'openid参数']]
	 * @return array[result_code => SUCCESS;  payment_no => 转账回单号] or string错误信息
	 */
	public function run($data)
	{
		$paymentConfig = $this->config();
		if(!$paymentConfig)
		{
			return '转账接口ID不存在';
		}

		//获取平台公钥信息
		$platPubkey = $this->getPlatPubkey();

		//计算数据
		$totalNums   = 0;
		$totalAmount = 0;
		$detail      = [];
		foreach($data['detail'] as $key => $item)
		{
			$totalNums++;
			$totalAmount += $item['amount']*100;

			$detail[] = [
				'out_detail_no'   => $data['transferNo'].$key,
				'transfer_amount' => intval($item['amount']*100),
				'transfer_remark' => $data['transferName'],
				'openid'          => $item['openid'],
				'user_name'       => $this->encode($item['name']),
			];
		}

		$sendData = [
			'appid'                => $paymentConfig['appid'],
			'out_batch_no'         => $data['transferNo'],
			'batch_name'           => $data['transferName'],
			'batch_remark'         => $data['transferName'],
			'total_amount'         => intval($totalAmount),
			'total_num'            => $totalNums,
			'transfer_detail_list' => $detail,
		];

		$result = $this->curlSubmit($this->getSubmitUrl(),$sendData,['Wechatpay-Serial: '.$platPubkey['serial_no']]);

		//日志记录
	    $logObj = new IFileLog('transfer/'.date('Y-m-d').'.log');
	    $logObj->write(['请求地址' => $this->getSubmitUrl(),'发送数据' => $sendData, '返回数据' => $result]);

		if(is_array($result) && $result)
		{
			if(isset($result['batch_id']) && $result['batch_id'])
			{
				$result['payment_no'] = $result['batch_id'];
				$result['result_code']= 'SUCCESS';
				return $result;
			}

			$message = isset($result['message']) ? $result['message'] : __CLASS__ . '转账接口失败';
			return $message;
		}
		else
		{
			return '余额转账返回值异常:'.$result;
		}
	}
}